#Torello Marinoni and Nishio et al. Development of high-density genetic linkage maps and identification of loci for chestnut gall wasp resistance in Castanea spp.
#File S1: Samtools-based pipeline. Bash script containing all the commands used in the Samtools-based pipeline adopted for SNP and indel mining


########## removing_adapters ##########

for i in $(cat list);
 do
  scythe -a illumina_adapters.fa  /home/vallauri/Dati/Sogo/RAW/"$i"_1.fastq.gz | pigz > trim_"$i"_1.fastq.gz;

  scythe -a illumina_adapters.fa  /home/vallauri/Dati/Sogo/RAW/"$i"_2.fastq.gz | pigz > trim_"$i"_2.fastq.gz;

########## cleaning of the reads ##########

 sickle pe -g -f trim_"$i"_1.fastq.gz -r trim_"$i"_2.fastq.gz    -o clean_trim_"$i"_1.fastq.gz -p clean_trim_"$i"_2.fastq.gz -s clean_trim_"$i"_singlet.fastq.gz -t sanger;

 rm trim_"$i"_1.fastq.gz;
 rm trim_"$i"_2.fastq.gz;

done

########## mapping of the reads ##########

bwa index -a bwtsw Cm_v1.1_scaffolds.fasta;

#”Cm_v1.1_scaffolds.fasta” is C. mollissima reference genome.

for i in $(cat list);
 do
  bwa mem Cm_v1.1_scaffolds.fasta clean_trim_"$i"_1.fastq.gz  clean_trim_"$i"_2.fastq.gz | samtools view -bS - | samtools sort - -o "$i"_pe.sort.bam; 
done

########## SNP calling ##########

samtools mpileup -gu -t DP -f Cm_v1.1_scaffolds.fasta B1-1_pe.sort.bam B1-2_pe.sort.bam B2_pe.sort.bam BMF1-001_pe.sort.bam BMF1-002_pe.sort.bam BMF1-003_pe.sort.bam [...]./BMF1-373_pe.sort.bam BMF1-374_pe.sort.bam M1-1_pe.sort.bam M1-2_pe.sort.bam M2_pe.sort.bam | bcftools call -c --threads 4 - | vcfutils.pl varFilter  -Q 20  - | pigz > 0_BxM_progeny_GBS.vcf.gz




########## SNP filtering ##########

vcftools --gzvcf 0_BxM_progeny_GBS.vcf.gz --minDP 10 --recode --out 1_BxM_progeny_GBS_TAG.vcf;

vcftools --vcf 1_BxM_progeny_GBS_TAG.vcf.recode.vcf  --max-missing-count 20 --recode --out 2_BxM_progeny_GBS_TAG_maxmissing_20.vcf

vcftools --vcf 2_BxM_progeny_GBS_TAG_magg10_maxmissing_20.vcf.recode.vcf --remove list_ind_to_remove --max-alleles 2 --maf 0.1 --max-maf 0.9 --recode --out 3_BxM_progeny_GBS_TAG_magg10_maxmissing_20_maf_rem.vcf

awk -v OFS='\t' '{print $1,$2,$3,$4,$5,$6,$7,$8,$9,$197,$198,$199,$10,$11,$12,$13,$14,$15,$16,$17,$18,$19,$20,$21,$22,$23,$24,$25,$26,$27,$28,$29,$30,$31,$32,$33,$34,$35,$36,$37,$38,$39,$40,$41,$42,$43,$44,$45,$46,$47,$48,$49,$50,$51,$52,$53,$54,$55,$56,$57,$58,$59,$60,$61,$62,$63,$64,$65,$66,$67,$68,$69,$70,$71,$72,$73,$74,$75,$76,$77,$78,$79,$80,$81,$82,$83,$84,$85,$86,$87,$88,$89,$90,$91,$92,$93,$94,$95,$96,$97,$98,$99,$100,$101,$102,$103,$104,$105,$106,$107,$108,$109,$110,$111,$112,$113,$114,$115,$116,$117,$118,$119,$120,$121,$122,$123,$124,$125,$126,$127,$128,$129,$130,$131,$132,$133,$134,$135,$136,$137,$138,$139,$140,$141,$142,$143,$144,$145,$146,$147,$148,$149,$150,$151,$152,$153,$154,$155,$156,$157,$158,$159,$160,$161,$162,$163,$164,$165,$166,$167,$168,$169,$170,$171,$172,$173,$174,$175,$176,$177,$178,$179,$180,$181,$182,$183,$184,$185,$186,$187,$188,$189,$190,$191,$192,$193,$194,$195,$196}' 3_BxM_progeny_GBS_TAG_magg10_maxmissing_20_maf_rem.vcf.recode.vcf > 3_BxM_progeny_GBS_TAG_magg10_maxmissing_20_maf_rem.vcf.recode_BMsort.vcf

